scan_stealth_address

Function scan_stealth_address 

pub fn scan_stealth_address(
    scan_secret: &Scalar,
    spend_secret: &Scalar,
    address: &StealthAddress,
) -> Option<Scalar>
Recipient scans for stealth addresses using their scan secret. Returns the one-time secret key if this address belongs to them.